@@ -3,21 +3,13 @@ from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli.experimental import (
-    dashboard,
-    list_labor_worktime,
-    list_labor_worktime_from_csv,
-    list_out_of_range_annotation_for_movie,
-)
+from annofabcli.experimental import list_out_of_range_annotation_for_movie
 
 
 def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
-    dashboard.add_parser(subparsers)
-    list_labor_worktime.add_parser(subparsers)
-    list_labor_worktime_from_csv.add_parser(subparsers)
     list_out_of_range_annotation_for_movie.add_parser(subparsers)
 
 
