@@ -80,10 +80,10 @@ class Database:
         self.query = query if query is not None else Query()
 
         # ダウンロードした一括情報
-        self.tasks_json_path = self.temp_dir / "tasks.json"
-        self.comment_json_path = temp_dir / "comments.json"
-        self.task_histories_json_path = temp_dir / "task_histories.json"
-        self.annotations_zip_path = temp_dir / "simple-annotations.zip"
+        self.tasks_json_path = self.temp_dir / f"{self.project_id}__tasks.json"
+        self.comment_json_path = temp_dir / f"{self.project_id}__comments.json"
+        self.task_histories_json_path = temp_dir / f"{self.project_id}__task_histories.json"
+        self.annotations_zip_path = temp_dir / f"{self.project_id}__simple-annotations.zip"
 
         self.logging_prefix = f"project_id={project_id}"
 
@@ -176,7 +176,7 @@ class Database:
     def wait_for_completion_updated_task_json(self, project_id):
         MAX_JOB_ACCESS = 120
         JOB_ACCESS_INTERVAL = 60
-        MAX_WAIT_MINUTU = MAX_JOB_ACCESS * JOB_ACCESS_INTERVAL / 60
+        MAX_WAIT_MINUTE = MAX_JOB_ACCESS * JOB_ACCESS_INTERVAL / 60
         result = self.annofab_service.wrapper.wait_for_completion(
             project_id,
             job_type=ProjectJobType.GEN_TASKS_LIST,
@@ -186,7 +186,7 @@ class Database:
         if result:
             logger.info(f"{self.logging_prefix}: タスク全件ファイルの更新が完了しました。")
         else:
-            logger.info(f"{self.logging_prefix}: タスク全件ファイルの更新に失敗しました or {MAX_WAIT_MINUTU} 分待っても、更新が完了しませんでした。")
+            logger.info(f"{self.logging_prefix}: タスク全件ファイルの更新に失敗しました or {MAX_WAIT_MINUTE} 分待っても、更新が完了しませんでした。")
             return
 
     def update_annotation_zip(self, project_id: str, should_update_annotation_zip: bool = False):
@@ -371,7 +371,6 @@ class Database:
 
         if isinstance(results[COMMENT_JSON_INDEX], DownloadingFileNotFoundError):
             # 空のJSONファイルを作り、検査コメント0件として処理する
-            # TODO おかしい
             self.comment_json_path.write_text("{}", encoding="utf-8")
         elif isinstance(results[COMMENT_JSON_INDEX], Exception):
             raise results[COMMENT_JSON_INDEX]
