@@ -71,7 +71,12 @@ class ProjectDir(DataClassJsonMixin):
 
     def read_task_list(self) -> Task:
         """`タスクlist.csv`を読み込む。"""
-        return Task.from_csv(self.project_dir / self.FILENAME_TASK_LIST)
+        file = self.project_dir / self.FILENAME_TASK_LIST
+        if file.exists():
+            return Task.from_csv(file)
+        else:
+            logger.warning(f"'{str(file)}'を読み込もうとしましたが、ファイルは存在しません。")
+            return Task.empty()
 
     def write_task_list(self, obj: Task):
         """`タスクlist.csv`を書き込む。"""
@@ -140,7 +145,12 @@ class ProjectDir(DataClassJsonMixin):
 
     def read_whole_performance(self) -> WholePerformance:
         """`全体の生産性と品質.csv`を読み込む。"""
-        return WholePerformance.from_csv(self.project_dir / self.FILENAME_WHOLE_PERFORMANCE)
+        file = self.project_dir / self.FILENAME_WHOLE_PERFORMANCE
+        if file.exists():
+            return WholePerformance.from_csv(file)
+        else:
+            logger.warning(f"'{str(file)}'を読み込もうとしましたが、ファイルは存在しません。")
+            return WholePerformance.empty()
 
     def write_whole_performance(self, whole_performance: WholePerformance):
         """`全体の生産性と品質.csv`を出力します。"""
@@ -195,7 +205,12 @@ class ProjectDir(DataClassJsonMixin):
         """
         メンバごとの生産性と品質の情報を読み込みます。
         """
-        return UserPerformance.from_csv(self.project_dir / self.FILENAME_USER_PERFORMANCE)
+        file = self.project_dir / self.FILENAME_USER_PERFORMANCE
+        if file.exists():
+            return UserPerformance.from_csv(file)
+        else:
+            logger.warning(f"'{str(file)}'を読み込もうとしましたが、ファイルは存在しません。")
+            return UserPerformance.empty()
 
     def write_user_performance(self, user_performance: UserPerformance):
         """
@@ -221,14 +236,19 @@ class ProjectDir(DataClassJsonMixin):
             )
         else:
             logger.warning(
-                f"実績作業時間の合計値が0なので、実績作業時間関係の以下のグラフは出力しません。:: "
+                f"実績作業時間の合計値が0なので、実績作業時間関係の次のグラフを'{output_dir}'に出力しません。:: "
                 "'散布図-アノテーションあたり作業時間と累計作業時間の関係-実績時間.html',"
                 "'散布図-アノテーションあたり作業時間と品質の関係-実績時間-教師付者用'"
             )
 
     def read_worktime_per_date_user(self) -> WorktimePerDate:
         """`ユーザ_日付list-作業時間.csvを読み込む。"""
-        return WorktimePerDate.from_csv(self.project_dir / self.FILENAME_WORKTIME_PER_DATE_USER)
+        file = self.project_dir / self.FILENAME_WORKTIME_PER_DATE_USER
+        if file.exists():
+            return WorktimePerDate.from_csv(file)
+        else:
+            logger.warning(f"'{str(file)}'を読み込もうとしましたが、ファイルは存在しません。")
+            return WorktimePerDate.empty()
 
     def write_worktime_per_date_user(self, obj: WorktimePerDate):
         """`ユーザ_日付list-作業時間.csvを書き込む"""
@@ -251,7 +271,9 @@ class ProjectDir(DataClassJsonMixin):
         """
         `project_info.json`を書き込む。
         """
-        print_json(project_info.to_dict(encode_json=True), output=self.project_dir / self.FILENAME_PROJECT_INFO, is_pretty=True)
+        print_json(
+            project_info.to_dict(encode_json=True), output=self.project_dir / self.FILENAME_PROJECT_INFO, is_pretty=True
+        )
 
     def read_merge_info(self) -> MergingInfo:
         """
@@ -265,7 +287,7 @@ class ProjectDir(DataClassJsonMixin):
         """
         `merge_info.json`を書き込む。
         """
-        print_json(obj.to_dict(), output=self.project_dir / self.FILENAME_MERGE_INFO, is_pretty=True)
+        print_json(obj.to_dict(encode_json=True), output=self.project_dir / self.FILENAME_MERGE_INFO, is_pretty=True)
 
 
 @dataclass
